# 만든 사람들

본 강의는 제주한라대학교 인공지능학과 이영준 교수가 직접 강의하고, 학부생들이 직접 참여하여 만들어졌습니다. 강의를 듣는 학생들은 강의를 듣는 것뿐만 아니라, 강의를 만드는 과정에 직접 참여하게 됩니다. 이를 통해 학생들은 강의를 듣는 것뿐만 아니라, 강의를 만드는 과정을 통해 실제로 배우고, 실제로 경험하게 됩니다.

## Instructor

### 이영준

```{image} images/yjlee.jpeg
:width: 130
:align: left
```

- 전공: 경영학(박사), 경제학(석사), 정보산업공학(학사)
- 관심분야: 인공지능, 자연어처리, Generative AI, Multimodal AI, Robotics, Sustainability
- 주요담당분야: 자연어처리, 생성형 AI, 빅데이터, DevOps & MLOps
- E-Mail: [yj.lee@chu.ac.kr](mailto:yj.lee@chu.ac.kr)
- 🏠: [entelecheia.me](https://entelecheia.me)

## Teaching Assistants

## Students
